;;; org-babel-maxima.el --- org-babel functions for maxima evaluation

;; Copyright (c) 2009 Eric S Fraga

;; based on code by
;; Copyright (C) 2009 Eric Schulte

;; Author: Eric Schulte
;; Keywords: literate programming, reproducible research
;; Homepage: http://orgmode.org
;; Version: 0.01

;;; License:

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to the
;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Org-Babel support for evaluating maxima entries.
;;
;; This differs from most standard languages in that
;;
;; 1) there is no such thing as a "session" in maxima
;;
;; 2) we are generally only going to return output from the leger program
;;
;; 3) we are adding the "cmdline" header argument
;;
;; 4) there are no variables

;;; Code:
;; (require 'org-babel)

;;(org-babel-add-interpreter "maxima")

;;(add-to-list 'org-babel-tangle-langs '("maxima" "maxima"))

(defvar org-babel-default-header-args:maxima
  '((:results . "output"))
  "Default arguments to use when evaluating a maxima source block.")

(defun org-babel-execute:maxima (body params)
  "Execute a block of Maxima entries with org-babel.  This function is
called by `org-babel-execute-src-block'."
  (message "executing Maxima source code block")
  (let ((result-params (split-string (or (cdr (assoc :results params)) "")))
	(cmdline (cdr (assoc :cmdline params)))
        (in-file (make-temp-file "org-babel-maxima"))
	(out-file (make-temp-file "org-babel-maxima-output"))
	)
    (with-temp-file in-file (insert body))
    (setq maximacommand (concat "maxima --very-quiet -r 'batchload(\"" in-file "\")$'" cmdline " | grep -v batch | grep -v 'replaced' | sed '/^$/d' " " > " out-file))
    (message maximacommand)
    (with-output-to-string (shell-command maximacommand))
    (with-temp-buffer (insert-file-contents out-file) (buffer-string))
    ))

(defun org-babel-prep-session:maxima (session params)
  (error "Maxima does not support sessions"))

(provide 'ob-maxima)
;;; org-babel-ledger.el ends here
